@@ -20,12 +20,6 @@ package EmailReminder::AnniversaryStore;
 use strict;
 use warnings;
 
-use Gtk2;
-use Glib::Object::Subclass
-    Glib::Object::,
-    interfaces => [ Gtk2::TreeModel:: ],
-    ;
-
 use EmailReminder::AnniversaryEvent;
 use EmailReminder::EventStore;
 
@@ -61,20 +55,4 @@ sub get_event_column
     }
 }
 
-sub set_event_column
-{
-    my ($self, $event, $col, $new_value) = @_;
-
-    if ($col == $PARTNER_NAME_INDEX) {
-        $event->set_partner_name($new_value);
-    }
-    elsif ($col == $PARTNER_EMAIL_INDEX) {
-        $event->set_partner_email($new_value);
-    }
-    else {
-        $self->EmailReminder::BirthdayStore::set_event_column($event, $col, $new_value);
-    }
-    return 1;
-}
-
 1;
