@@ -69,7 +69,7 @@ sub get_subject
 
     my $name = $self->get_name();
     my $age  = $self->get_occurence();
-    my $when = $self->{"WHEN"};
+    my $when = $self->{"WHEN"} || '';
 
     if ($age and $when eq "today") {
         return "$name is now $age";
@@ -87,7 +87,7 @@ sub get_message_body
     my $name  = $self->get_name();
     my $email = $self->get_email();
     my $age   = $self->get_occurence();
-    my $when  = $self->{"WHEN"};
+    my $when  = $self->{"WHEN"} || '';
     
     my $age_string = $age ? "turning $age" : "getting one year older";
     my $email_message = $email ? "\n\nYou can reach $name at $email." : "";
