@@ -20,12 +20,6 @@ package EmailReminder::BirthdayStore;
 use strict;
 use warnings;
 
-use Gtk2;
-use Glib::Object::Subclass
-    Glib::Object::,
-    interfaces => [ Gtk2::TreeModel:: ],
-    ;
-
 use EmailReminder::BirthdayEvent;
 use EmailReminder::EventStore;
 
@@ -57,17 +51,4 @@ sub get_event_column
     }
 }
 
-sub set_event_column
-{
-    my ($self, $event, $col, $new_value) = @_;
-
-    if ($col == $EMAIL_INDEX) {
-        $event->set_email($new_value);
-    }
-    else {
-        $self->EmailReminder::YearlyStore::set_event_column($event, $col, $new_value);
-    }
-    return 1;
-}
-
 1;
