@@ -127,15 +127,6 @@ sub new
     return $self;
 }
 
-sub unlink_event
-{
-    my $self = shift;
-    my $node = $self->{XML_NODE};
-    $node->getParentNode()->removeChild($node);
-    $node->dispose();
-    return 1;
-}
-
 sub get_recipients
 {
     my $self = shift;
@@ -218,59 +209,6 @@ sub get_reminders
     return $self->{REMINDERS_CACHE};
 }
 
-sub set_reminders
-{
-    my ($self, $new_reminders) = @_;
-
-    my $event = $self->{XML_NODE};
-    my $doc = $event->getOwnerDocument();
-    my $reminders = $self->{REMINDERS_NODE};
-
-    if (!defined($reminders)) {
-        # Create a blank <reminders> tag
-        $reminders = $doc->createElement($REMINDERS_TAG);
-        $event->appendChild($reminders);
-
-        $self->{REMINDERS_NODE} = $reminders;
-    }
-    else {
-        # TODO: preserve extra reminders in the XML but not in the UI
-
-        # Delete all current reminders
-        foreach my $child ($reminders->getChildNodes()) {
-            $reminders->removeChild($child);
-        }
-    }
-    
-    # Add all reminders to the <reminders> node
-    foreach my $nb_days (@$new_reminders)
-    {
-        my $new_node = $doc->createElement($REMINDER_TAG);
-        
-        if ($nb_days == 0)
-        {
-            $new_node->setAttribute($TYPE_ATTR, $SAME_DAY_VAL);
-        }
-        elsif ($nb_days > 0)
-        {
-            $new_node->setAttribute($TYPE_ATTR, $DAYS_BEFORE_VAL);
-            $new_node->addText($nb_days);
-        }
-        else
-        {
-            # Invalid number, ignore
-                next;
-            }
-        
-        $reminders->appendChild($new_node);
-    }
-
-    # Clear the cache
-    undef $self->{REMINDERS_CACHE};
-
-    return 1;
-}
-
 sub is_occurring
 {
     my $self = shift;
